Subject: [PATCH 11/11] dm: raid1: reset sync_search on resume
To: Andrew Morton <akpm@osdl.org>
Cc: linux-kernel@vger.kernel.org, dm-devel@redhat.com, Jonathan E Brassow <jbrassow@redhat.com>

From: Jonathan E Brassow <jbrassow@redhat.com>

Reset sync_search on resume.
The effect is to retry syncing all out-of-sync regions when a mirror is resumed,
including ones that previously failed.

Signed-off-by: Jonathan E Brassow <jbrassow@redhat.com>
Signed-off-by: Alasdair G Kergon <agk@redhat.com>
Cc: dm-devel@redhat.com

 drivers/md/dm-log.c |    9 +++++++++
 1 files changed, 9 insertions(+)

Index: linux-2.6.19/drivers/md/dm-log.c
===================================================================
--- linux-2.6.19.orig/drivers/md/dm-log.c	2006-12-06 20:49:33.000000000 +0000
+++ linux-2.6.19/drivers/md/dm-log.c	2006-12-06 20:49:34.000000000 +0000
@@ -466,6 +466,7 @@ static int disk_resume(struct dirty_log 
 	/* copy clean across to sync */
 	memcpy(lc->sync_bits, lc->clean_bits, size);
 	lc->sync_count = count_bits32(lc->clean_bits, lc->bitset_uint32_count);
+	lc->sync_search = 0;
 
 	/* set the correct number of regions in the header */
 	lc->header.nr_regions = lc->region_count;
@@ -480,6 +481,13 @@ static uint32_t core_get_region_size(str
 	return lc->region_size;
 }
 
+static int core_resume(struct dirty_log *log)
+{
+	struct log_c *lc = (struct log_c *) log->context;
+	lc->sync_search = 0;
+	return 0;
+}
+
 static int core_is_clean(struct dirty_log *log, region_t region)
 {
 	struct log_c *lc = (struct log_c *) log->context;
@@ -621,6 +629,7 @@ static struct dirty_log_type _core_type 
 	.module = THIS_MODULE,
 	.ctr = core_ctr,
 	.dtr = core_dtr,
+	.resume = core_resume,
 	.get_region_size = core_get_region_size,
 	.is_clean = core_is_clean,
 	.in_sync = core_in_sync,
